| Title: | Data from the Australian Census 2016 |
|---|---|
| Description: | Contains selected variables from the time series profiles for statistical areas level 2 from the 2006, 2011, and 2016 censuses of population and housing, Australia. Also provides methods for viewing the questions asked for convenience during analysis. |
| Authors: | Hugh Parsonage [aut, cre], Nick Evershed [dtc], Australian Bureau of Statistics [cph] |
| Maintainer: | Hugh Parsonage <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.2.0 |
| Built: | 2026-05-15 06:11:58 UTC |
| Source: | https://github.com/hughparsonage/census2016 |
Census data by SA2
Census2016_wide_by_SA2_yearCensus2016_wide_by_SA2_year
An object of class data.table (inherits from data.frame) with 6720 rows and 43 columns.
If no data is offered by the ABS for that SA2, the data is marked as missing and the column isMissing is TRUE.
View census form for particular question
see_question(...) ## S3 method for class 'data.frame' see_question(.data, ...) ## S3 method for class 'numeric' see_question(qn, ...)see_question(...) ## S3 method for class 'data.frame' see_question(.data, ...) ## S3 method for class 'numeric' see_question(qn, ...)
... |
Passed to method: either a question number or a data frame. |
.data |
A |
qn |
Question number. |
Primarily called for its side effect: plots an image of the question (and available answers, if appropriate) in the plot window.
If a data.frame from this package is called, it is returned (invisibly if knitr.in.progress is TRUE).
## Not run: see_question(5) see_question(Census2016_languages) ## End(Not run)## Not run: see_question(5) see_question(Census2016_languages) ## End(Not run)
Tables with two keys (the SA2 and a label for which the count applies)
Census2016_ancestories Census2016_countries_of_birth Census2016_languages Census2016_religions Census2016_n_women_by_children_ever_bornCensus2016_ancestories Census2016_countries_of_birth Census2016_languages Census2016_religions Census2016_n_women_by_children_ever_born
A data.table of 4 columns. The keys are sa2_code
From the Community Series time series data packs.
N.B. countries_of_birth only includes the top 35 responses countries of birth across Australia.
sa2_code is not necessarily the same as SA2_MAINYY for 2006, 2011, and 2016.
Instead, the code reflects the 2016 boundaries and the values given allow comparisons to be made over time on these boundaries.
Census2016_ancestoriesN.B. This table is a multi-response table, and therefore the total response count will not equal the total persons count. Sinhalese is equivalent to Sri Lankan.
sa2_codeThe SA2 code. See details.
yearThe census year.
ancestorySelected ancestries are based on the 30 most common ancestry responses reported in the 2011 Census.
personsCount of persons.
Census2016_religionssa2_codeThe SA2 code. See details.
yearThe census year.
religionReligion. "What is the person's religion?".
personsNumber of adherents.
Census2016_languagessa2_codeThe SA2 code. See details.
yearThe census year.
languageDoes the person speak a language other than English at home?
personsNumber of persons who speak the specified language. Note that the complement of "English" is not the number of people who do not speak English.
Census2016_n_women_by_children_ever_bornsa2_codeThe SA2 code. See details.
yearThe census year.
n_children_ever_bornNumber of children ever born.
n_womenCount of females over 15 by the number of children they have ever given birth to.